Fixes #

## Proposed Changes

-

## Tests added

-

## Checklist

- [ ] change approved
- [ ] implementation finished
- [ ] correct namespace imported
- [ ] tests added
- [ ] CHANGELOG updated
- [ ] (if new public method/class) docs in rst file updated?
